Changelog
=========


1.2.0 (2019-05-10)
------------------

- Use chardet package to detect the encoding of the embedded page.
  [rodfersou]


1.1.0 (2019-04-18)
------------------

- Move stylesheets from head to body.
  [rodfersou]

- Add tests.
  [rodfersou]

- Add data-embedded attribute to inspect what page
  is being embedded with no need to login.
  [rodfersou]


1.0.2 (2019-03-30)
------------------

- Fix the content type when request script.
  [rodfersou]

- Fix iframe relative path to full path.
  [rodfersou]


1.0.1 (2019-03-28)
------------------

- Forward script requests from plone server.
  [rodfersou]

- Forward requests and params to original page.
  [rodfersou]

- Convert html parsed data to string with html method.
  [rodfersou]


1.0.0 (2019-02-23)
------------------

- Re-release 1.0.0a6 as final release.
  [timo]


1.0.0a6 (2019-02-13)
--------------------

- Add extra standard behaviors.
  [rodfersou]


1.0.0a5 (2019-02-12)
--------------------

- Fix when html is encoded as UTF-8.
  [rodfersou]


1.0.0a4 (2019-02-11)
--------------------

- Fix when there is no body tag inside html.
  [rodfersou]


1.0.0a3 (2019-01-22)
--------------------

- Add Rich Text to add content before the page embedded.
  [rodfersou]

- Add Rich Text to add content after the page embedded.
  [rodfersou]

- Add One parameter to disable right portlet column.
  [rodfersou]


1.0.0a2 (2019-01-14)
--------------------

- Do not show title and description of the content page itself.
  [timo]

- Add pypi classifier for development status.
  [timo]


1.0.0a1 (2018-11-01)
--------------------

- Initial release.
  [kitconcept]
